<?php
/** Ewe (Eʋegbe)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Natsubee
 */

$messages = array(
# User preference toggles
'tog-hideminor'            => 'Ɣla tɔtrɔ suewo le tɔtrɔ yeyeawo me',
'tog-watchcreations'       => 'Tsɔ axa siwo gɔme medze la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdefault'         => 'Tsɔ axa siwo ŋu metrɔ asi le la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchmoves'           => 'Tsɔ axa siwo ƒe nɔƒe meɖɔli la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdeletion'        => 'Tsɔ axa siwo metutu la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-enotifwatchlistpages' => 'Ɖo du nam ne axa aɖe si ŋu nyeƒe ŋku le la trɔ',

'underline-always' => 'Ɣesiaɣi',
'underline-never'  => 'Gbeɖe',

# Dates
'sunday'        => 'Kɔsiɖagbe',
'monday'        => 'Dzoɖagbe',
'tuesday'       => 'Brãɖagbe',
'wednesday'     => 'Kuɖagbe',
'thursday'      => 'Yawoɖagbe',
'friday'        => 'Fiɖagbe',
'saturday'      => 'Memleɖagbe',
'sun'           => 'Kɔs',
'mon'           => 'Dzo',
'tue'           => 'Brã',
'wed'           => 'Kuɖ',
'thu'           => 'Yaw',
'fri'           => 'Fiɖ',
'sat'           => 'Mem',
'january'       => 'Dzove',
'february'      => 'Dzodze',
'march'         => 'Tedoxe',
'april'         => 'Afɔfiɛ',
'may_long'      => 'Damɛ',
'june'          => 'Masa',
'july'          => 'Siamlɔm',
'august'        => 'Dasiamime',
'september'     => 'Anyɔnyɔ',
'october'       => 'Kele',
'november'      => 'Adeɛmekpɔxe',
'december'      => 'Dzome',
'january-gen'   => 'Dzove',
'february-gen'  => 'Dzodze',
'march-gen'     => 'Tedoxe',
'april-gen'     => 'Afɔfiɛ',
'may-gen'       => 'Damɛ',
'june-gen'      => 'Masa',
'july-gen'      => 'Siamlɔm',
'august-gen'    => 'Dasiamime',
'september-gen' => 'Anyɔnyɔ',
'october-gen'   => 'Kele',
'november-gen'  => 'Adeɛmekpɔxe',
'december-gen'  => 'Dzome',
'jan'           => 'Dzov',
'feb'           => 'Dzod',
'mar'           => 'Ted',
'apr'           => 'Afɔ',
'may'           => 'Damɛ',
'jun'           => 'Mas',
'jul'           => 'Sia',
'aug'           => 'Das',
'sep'           => 'Any',
'oct'           => 'Kel',
'nov'           => 'Ade',
'dec'           => 'Dzom',

# Categories related messages
'listingcontinuesabbrev' => 'yi dzi',

'about'      => 'Ŋutinya',
'newwindow'  => '(eʋua fesre yeye)',
'cancel'     => 'Dzudzɔ etɔtrɔ',
'mypage'     => 'Axa nye',
'mytalk'     => 'Nyeƒe nyamedzroƒe',
'navigation' => 'Mɔtabiala',
'and'        => '&#32;kpakple',

# Cologne Blue skin
'qbfind'         => 'Di',
'qbedit'         => 'Trɔ asi le eŋu',
'qbpageoptions'  => 'Axa sia',
'qbmyoptions'    => 'Nyeƒe axawo',
'qbspecialpages' => 'Axa tɔxewo',

# Vector skin
'vector-action-delete'   => 'Tutui',
'vector-action-move'     => 'Ɖɔli eƒe nɔƒe',
'vector-view-create'     => 'Dze egɔme',
'vector-view-edit'       => 'Trɔ asi le eŋu',
'vector-view-history'    => 'Kpɔ xoxoawo',
'vector-view-view'       => 'Xlẽ',
'vector-view-viewsource' => 'Kpɔ alesi woŋlɔe',

'errorpagetitle'   => 'Vodada',
'returnto'         => 'Gbugbɔ yi $1.',
'tagline'          => 'Tso {{SITENAME}}',
'help'             => 'Kpekpeɖeŋu',
'search'           => 'Dii',
'searchbutton'     => 'Dii',
'go'               => 'Yi',
'searcharticle'    => 'Yi',
'history'          => 'Axa sia ƒe tata xoxoawo',
'history_short'    => 'Xoxoawo',
'edit'             => 'Trɔ asi le eŋu',
'create'           => 'Dze egɔme',
'editthispage'     => 'Ðɔ axa sia ɖo',
'create-this-page' => 'Dze axa sia gɔme',
'delete'           => 'Tutui',
'deletethispage'   => 'Tutu axa sia',
'protect'          => 'Dzɔ eŋu',
'protect_change'   => 'ɖɔlii',
'protectthispage'  => 'Dzɔ axa sia ŋu',
'newpage'          => 'Axa yeye',
'talkpagelinktext' => 'Nyamedzroƒe',
'specialpage'      => 'Axa Tɔxe',
'personaltools'    => 'Wòƒe dɔwɔnuwo',
'postcomment'      => 'Akpa yeye',
'talk'             => 'Nyamedzroƒe',
'toolbox'          => 'Dɔwɔnuɖaka',
'otherlanguages'   => 'Le gbe bubuwo me',
'redirectedfrom'   => '(Woɖo wò ɖe afii tso $1)',
'lastmodifiedat'   => 'Wó ɖɔ axa sia ɖo susue le $2 le ŋkeke $1 dzi.',
'viewcount'        => 'Wokpɔ axa sia zi {{PLURAL:$1|ɖeka|$1 sɔ̃}}.',
'jumpto'           => 'Dzo yi:',
'jumptonavigation' => 'kuɖɔɖoɖo',
'jumptosearch'     => 'dii',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} ŋutinya',
'aboutpage'            => 'Project:Ŋutinya',
'copyright'            => 'Nusiwo le afii le $1 mɔɖeɖea te.',
'copyrightpage'        => '{{ns:project}}:Mɔɖeɖewo',
'currentevents'        => 'Amaneɛ',
'currentevents-url'    => 'Project:Nusiwo le dzɔdzɔm',
'disclaimers'          => 'Nuxlɔ̃amenyawo',
'edithelp'             => 'Kpekpeɖeŋu na etɔtrɔ',
'mainpage'             => 'Axa do Ŋgɔ',
'mainpage-description' => 'Axa do ŋgɔ',
'portal'               => 'Takpekpewɔƒe',
'portal-url'           => 'Project:Takpekpewɔƒe',

'badaccess'        => 'Mɔɖeɖe vodada',
'badaccess-group0' => 'Se meɖe mɔ be nawɔ nusi wòle babiam be yeawɔ o.',

'retrievedfrom'           => 'Nuŋɔŋlɔ sia tso "$1"',
'youhavenewmessages'      => '$1 le asiwo ($2).',
'newmessageslink'         => 'du yeyewo',
'newmessagesdifflink'     => 'tɔtrɔ mamlea',
'youhavenewmessagesmulti' => 'Du yeyewo le asiwo le $1',
'editsection'             => 'trɔ asi le eŋu',
'editold'                 => 'trɔ asi le eŋu',
'viewsourceold'           => 'kpɔ alesi wó ŋlɔe',
'editlink'                => 'trɔ asi le eŋu',
'viewsourcelink'          => 'kpɔ alesi woŋlɔe',
'editsectionhint'         => 'Trɔ akpa: $1',
'toc'                     => 'Emenyawo',
'showtoc'                 => 'fia',
'hidetoc'                 => 'ɣla',
'thisisdeleted'           => 'Kpɔ $1 alo wòa gbugbɔe ve hã?',
'viewdeleted'             => 'Wòa kpɔ $1 a?',
'red-link-title'          => '$1 (womeŋlɔ axa sia haɖeke o)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Axa',
'nstab-user'      => 'Ezãla axa',
'nstab-special'   => 'Axa tɔxe',
'nstab-image'     => 'Agbalẽ',
'nstab-mediawiki' => 'Du',

# General errors
'error'           => 'Vodada',
'badarticleerror' => 'Wòmateŋu awɔ nusia le axa sia dzi o.',
'cannotdelete'    => 'Womateŋu atutu axa sia alo axa "$1" o.
Ɖewomahĩ ame aɖe tutui xoxo.',
'badtitle'        => 'Tanya gbegblẽ',
'viewsource'      => 'Kpɔ alesi wowɔe',
'viewsourcefor'   => '$1 tɔwo',

# Login and logout pages
'remembermypassword'         => 'Ɖo ŋku nyeƒe dzesi ŋkɔ dzi le mɔ sia dzi (vaseɖe {{PLURAL:$1|ŋkeke|ŋkeke}} $1 megbe)',
'login'                      => 'Ge ɖe eme',
'nav-login-createaccount'    => 'Geɖe me / Ŋlɔ ŋkɔ',
'userlogin'                  => 'Ge ɖe eme / ŋlɔ ŋkɔ daɖi',
'logout'                     => 'Do le eme',
'userlogout'                 => 'Do le eme',
'nologin'                    => "Wòmeŋlɔ ŋkɔ oa? '''$1'''.",
'nologinlink'                => 'Ŋlɔ ŋkɔ daɖi',
'createaccount'              => 'Ŋlɔ ŋkɔ daɖi',
'gotaccount'                 => "Wò ŋlɔ ŋkɔ xoxoa? '''$1'''.",
'gotaccountlink'             => 'Ge ɖe eme',
'loginsuccesstitle'          => 'Wò ge ɖe eme azɔ̃.',
'loginsuccess'               => "'''Wò le {{SITENAME}} me fifia abe \"\$1\" ene.'''",
'nouserspecified'            => 'Elebe na ŋlɔ ŋkɔ si wò zãna',
'acct_creation_throttle_hit' => "Wiki sia zãla aɖe tso wò ''IP address'' ŋlɔ {{PLURAL:$1|1 ŋkɔ|$1 ŋkɔwo}} le ŋkeke si vayi me xoxo. Mɔɖeɖe le na ŋkɔ  ɖeka ko ŋɔŋlɔ le ŋkeke ɖeka me.<br />
Le esiata la, ''IP address'' sia zãlawo mekpɔ mɔ aŋlɔ ŋkɔ bubuwo fifia o.",
'loginlanguagelabel'         => 'Gbe: $1',

# Edit page toolbar
'sig_tip' => 'Dzesiwò kple gaƒoƒoa',

# Edit pages
'subject'                          => 'Ta nya:',
'minoredit'                        => 'Esia nye tɔtrɔ sue aɖe ko',
'watchthis'                        => 'Le ŋku ɖe axa sia ŋu',
'savearticle'                      => 'Dzra axa sia ɖo',
'preview'                          => 'Kpɔe do ŋgɔ',
'showpreview'                      => 'Fiae do ŋgɔ',
'showdiff'                         => 'Fia tɔtrɔwo',
'newarticle'                       => '(Yeye)',
'newarticletext'                   => "Eva ɖo axa si gɔme womedze haɖeke o. Ne wòadi be yeadze egɔme la, dze nuŋlɔm ɖe go sia me le afi sia ɖome (kpɔ [[{{MediaWiki:Helppage}}|kpekpeɖeŋu nyawo]] na kpekpeɖeŋu bubuwo). Ne wòme ɖoe be yeava afii hafi o la, ekema tia '''megbe''' eye wòa gbugbɔ ayi afisi wòtso va.",
'previewnote'                      => "'''Ɖo ŋku edzi be wole afii fiam do ŋgɔ, wome dzrae ɖo haɖeke o!'''",
'editing'                          => '$1 na etɔtrɔ',
'editingsection'                   => 'Wòle $1 (ƒe akpa aɖe) trɔm',
'yourtext'                         => 'Wò nuŋɔŋlɔ',
'yourdiff'                         => 'Vovototowo',
'copyrightwarning'                 => "Taflatse, mítsɔe be nusiwo katã netsɔ kpe ɖe {{SITENAME}} ŋu lii fãa le $2 la nu (kpɔ $1 me nyawo). Ne madze ŋuwò be amebubuwo natrɔ asi le nusiwo newɔ ŋuti o, eye woagbugbɔ dɔsiwo newɔ ama na amebubuwo fãa o la, mega dae ɖe afisia o.<br /> Wòle ŋugbe dom na mí bena wò ŋutɔe ŋlɔ nusiawo, alo etsɔe tso afisi mɔɖeɖe li fãa be amesiame na tsɔ nuwo tso afima fãa. '''Mega da nusiwo ŋu mɔɖeɖe meli na o la ɖe afisia o!'''",
'permissionserrorstext-withaction' => 'Se meɖe mɔ bena na $2 o, le {{PLURAL:$1|ta|ta}}:',
'edit-already-exists'              => 'Wòmateŋu adze axa sia gɔme o.<br />
Wo ŋlɔe xoxo.',

# History pages
'currentrev-asof'      => 'Tata susue le $1 dzi',
'revisionasof'         => 'Tataa le $1',
'revision-info'        => 'Tataa le $1 si $2 wɔ',
'previousrevision'     => '← Tata xoxoa',
'nextrevision'         => 'Tata yeyea →',
'currentrevisionlink'  => 'Tata susuea',
'cur'                  => 'yeyea',
'next'                 => 'eyome',
'last'                 => 'mamlea',
'page_first'           => 'gbãtɔ',
'page_last'            => 'mamlea',
'histlegend'           => "Vovo tatia: de dzesi tata siwo ƒe vovototowo wò di be yea kpɔ ɖa eye na tia 'enter' alo kpe si le eɖome.<br />
Gɔmeɖeɖe: '''({{int:cur}})''' = vovototo tso tata mamlea gbɔ, '''({{int:last}})''' = vovototo tso tata si do ŋgɔ gbɔ, '''{{int:minoreditletter}}''' = tɔtrɔ sue.",
'history-show-deleted' => 'Esiwo wotutu ko',
'histfirst'            => 'Xoxoɔwu',
'histlast'             => 'Yeyeɛwu',

# Revision feed
'history-feed-item-nocomment' => '$1 le $2',
'history-feed-empty'          => 'Axa si dim wòle meli o.
Dewomahĩ, wotutui le wiki sia dzi alo wotrɔ eƒe ŋkɔ.
Zã [[Special:Search|nuwo didi le wiki sia dzi]] kpɔ na axa yeyeawo.',

# Revision deletion
'rev-delundel'          => 'fia/ɣla',
'rev-showdeleted'       => 'fia',
'revdelete-radio-same'  => '(megatrɔe o)',
'revdelete-radio-set'   => 'Yo',
'revdelete-radio-unset' => 'Kpao',
'revdelete-hid'         => 'ɣla $1',
'revdelete-unhid'       => 'megaɣla $1 o',

# Diffs
'history-title'           => '"$1" ƒe tata xoxoawo',
'difference'              => '(Vovototowo le tata xoxoawo me)',
'lineno'                  => 'Fli $1:',
'compareselectedversions' => 'Kpɔ tata siwo wotia la',

# Search results
'searchresults'                  => 'Nusiwo wòdi',
'searchresults-title'            => 'Nusiwo wofɔ le "$1" didi me',
'searchsubtitle'                 => 'Nusi wòdi enye \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|axawo katã siwo dze egɔme kple "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|axawo katã siwo kuɖe "$1" ŋu]]).',
'searchsubtitleinvalid'          => "Wòdi '''$1'''",
'notitlematches'                 => 'Mesɔ axa aɖeke ƒe tanya o',
'notextmatches'                  => 'Axa aɖeke ƒe nyawo mesɔ kple nyasiawo o.',
'prevn'                          => '{{PLURAL:$1|$1}} do ŋgɔ',
'nextn'                          => '{{PLURAL:$1|$1}} yometɔwo',
'viewprevnext'                   => 'Kpɔ ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists'              => "'''Axa si ŋkɔ enye \"[[:\$1]]\" le wiki sia dzi'''",
'searchmenu-new'                 => "'''Dze axa \"[[:\$1]]\" sia ŋlɔm ɖe wiki la dzi!'''",
'searchprofile-everything'       => 'Nuɖesiaɖe',
'searchprofile-articles-tooltip' => 'Dii le $1',
'searchprofile-project-tooltip'  => 'Dii le $1',
'search-result-size'             => '$1 ({{PLURAL:$2|nya 1|nya $2}})',
'search-suggest'                 => 'Ɖe wò be: $1',
'search-interwiki-more'          => '(kɔ kpe ɖe eŋu)',
'searchall'                      => 'wokatã',
'powersearch'                    => 'Dii de eme',
'powersearch-field'              => 'Di',
'powersearch-toggleall'          => 'Wokatã',

# Preferences page
'preferences'              => 'Didiwo',
'mypreferences'            => 'Nyeƒe didiwo',
'skin-preview'             => 'Kpɔe do ŋgɔ',
'prefs-datetime'           => 'Ŋkeke kple gaƒoƒo',
'prefs-watchlist-days-max' => 'Vaseɖe ŋkeke 7',
'timezoneregion-africa'    => 'Afrika',
'yourlanguage'             => 'Gbe:',
'yournick'                 => 'Dzesi',
'gender-male'              => 'Ŋutsu',
'gender-female'            => 'Nyɔnu',

# Groups
'group'       => 'Hame:',
'group-bot'   => 'Bɔtwo',
'group-sysop' => 'Dɔdzikpɔlawo',
'group-all'   => '(wokatã)',

# Associated actions - in the sentence "You do not have permission to X"
'action-read' => 'xlẽ axa sia',
'action-edit' => 'trɔ asi le axa sia ŋu',

# Recent changes
'recentchanges'        => 'Tɔtrɔ yeyewo',
'recentchanges-legend' => 'Tatiawo na tɔtrɔ yeyewo',
'rcnote'               => "Afisia wofia {{PLURAL:$1|tɔtrɔ '''1''' susue|tɔtrɔ '''$1''' susuewo}} le {{PLURAL:$2|ŋkeke si|ŋkeke '''$2''' mamleawo siwo}} vayi la me, le $5, $4.",
'rcnotefrom'           => "Tɔtrɔwo siwo wowɔ tso '''$2''' (wofia vaseɖe '''$1''') le afii.",
'rclistfrom'           => 'Fia tɔtrɔ yeyewo tso $1',
'rcshowhideminor'      => '$1 tɔtrɔ suewo',
'rcshowhidebots'       => '$1 bɔtwo',
'rcshowhideliu'        => '$1 ezãla siwo ŋlɔ ŋkɔ',
'rcshowhideanons'      => '$1 ŋkɔ maŋlɔlawo',
'rcshowhidemine'       => '$1 nyeƒe tɔtrɔwo',
'rclinks'              => 'Fia tɔtrɔ $1 mamleawo le ŋkeke $2 siwo vayi me<br />$3',
'diff'                 => 'tɔtrɔ',
'hist'                 => 'xoxo',
'hide'                 => 'Ɣla',
'show'                 => 'Fia',
'minoreditletter'      => 's',
'newpageletter'        => 'Y',

# Recent changes linked
'recentchangeslinked'         => 'Tɔtrɔ siwo kaa afii',
'recentchangeslinked-feed'    => 'Tɔtrɔ siwo kaa afii',
'recentchangeslinked-toolbox' => 'Tɔtrɔ siwo kaa afii',
'recentchangeslinked-title'   => 'Tɔtrɔ siwo ku ɖe "$1" ŋu',
'recentchangeslinked-page'    => 'Axaa ƒe ŋkɔ',

# Upload
'upload'    => 'Ɖo agbalẽ ɖa',
'uploadbtn' => 'Ɖo agbalẽ ɖa',

# File description page
'file-anchor-link'   => 'Agbalẽ',
'filehist'           => 'Axa sia ƒe tata xoxoawo',
'filehist-help'      => 'Tia ŋkeke/gaƒoƒo ɖeka ne wòadi be yea kpɔ axa sia ƒe tata le ɣemaɣi',
'filehist-deleteone' => 'tutui',
'filehist-datetime'  => 'Ŋkeke/Gaƒoƒo',
'filehist-user'      => 'Ezãla',
'linkstoimage'       => 'Axa {{PLURAL:$1|sia|$1 siawo}} ku ɖe agbalẽ sia ŋu.',
'sharedupload'       => "Agbalɛ̃ sia tso $1 eye dɔ (''alo project'') bubuawo woateŋu azãe fãa.",

# File deletion
'filedelete-submit' => 'Tutui',

# MIME search
'mimesearch' => 'MIME me didi',

# Random page
'randompage'         => 'Axaa ɖe ko',
'randompage-nopages' => 'Axa aɖeke mele "$1" o.',

# Statistics
'statistics' => 'Akɔntawo',

'brokenredirects-edit'   => 'trɔ asi le eŋu',
'brokenredirects-delete' => 'tutui',

'fewestrevisions' => 'Axawo siwo womeɖɔɖo zã o',

# Miscellaneous special pages
'wantedpages'    => 'Axawo siwo le hahĩam',
'mostrevisions'  => 'Axawo siwo woɖɔɖo wu',
'shortpages'     => 'Axa kpuiwo',
'longpages'      => 'Axa didiwo',
'protectedpages' => 'Axawo siwo ŋu wole dzɔdzɔm',
'listusers'      => 'Ezãlawo ƒe xexlẽme',
'usercreated'    => 'Wodze egɔme le ŋkeke $1 dzi le gaƒoƒo $2 me.',
'newpages'       => 'Axa yeyewo',
'ancientpages'   => 'Axawo si wo do xoxo wu',
'move'           => 'Ɖɔli eƒe nɔƒe',
'movethispage'   => 'Ɖɔli axa sia ƒe nɔƒe',
'pager-newer-n'  => '{{PLURAL:$1|1 yeyea|$1 yeyeawo}}',
'pager-older-n'  => '{{PLURAL:$1|1 xoxoa|$1 xoxoawo}}',

# Book sources
'booksources'               => 'Agbalɛ̃wo ƒe tsoƒe',
'booksources-search-legend' => 'Di agbalẽwo ƒe tsoƒewo',
'booksources-go'            => 'Yi',

# Special:Log
'specialloguserlabel'  => 'Ezãla:',
'speciallogtitlelabel' => 'Ta nya:',

# Special:AllPages
'allpages'       => 'Axawo katã',
'alphaindexline' => '$1 vaseɖe $2',
'nextpage'       => 'Axa yometɔ ($1)',
'prevpage'       => 'Axa do ŋgɔ ($1)',
'allpagesfrom'   => 'Fia axawo tso:',
'allpagesto'     => 'Fia axawo vaseɖe:',
'allarticles'    => 'Axawo katã',
'allinnamespace' => 'Axawo katã ($1 namespace)',
'allpagesnext'   => 'Eyome',
'allpagessubmit' => 'Yi',

# Special:LinkSearch
'linksearch-ok' => 'Dii',

# Special:Log/newusers
'newuserlogpage'           => 'Ŋkɔŋlɔla yeyewo ƒe xexlẽme',
'newuserlog-create-entry'  => 'Nuŋlɔla yeye',
'newuserlog-create2-entry' => 'woŋlɔ ŋkɔ yeye na $1',

# Special:ListGroupRights
'listgrouprights-group' => 'Hame',

# Watchlist
'watch'         => 'Le ŋku ɖe eŋu',
'watchthispage' => 'Le ŋku ɖe axa sia ŋu',
'wlnote'        => "Afisia wofia {{PLURAL:$1|tɔtrɔ '''1''' mamlea|tɔtrɔ '''$1''' mamleawo}} le {{PLURAL:$2|gaƒoƒo mamlea si|gaƒoƒo '''$2''' mamleawo siwo}} vayi la me.",
'wlshowlast'    => 'Fia gaƒoƒo $1 ŋkeke $2 mamleawo. $3',

# Delete
'deletepage'     => 'Tutu axa sia',
'exblank'        => 'axa la le gbɔlo',
'delete-confirm' => 'Tutu "$1"',
'delete-legend'  => 'Tutui',
'actioncomplete' => 'Wowɔe vɔ',
'deletedarticle' => 'wotutu "[[$1]]"',
'dellogpagetext' => 'Afisia wofia axa mamleawo siwo wotutu la',

# Protect
'prot_1movedto2'              => '[[$1]] wohee yi [[$2]]',
'protect-default'             => 'Namɔ ezãlawo katã',
'protect-level-autoconfirmed' => 'Xemɔ na ame yeyewo kple ŋkɔmaŋlɔlawo',
'protect-expiring'            => 'ewunu $1 (UTC)',
'protect-existing-expiry'     => 'Nuwuwu gaƒoƒo: $3, $2"',
'protect-expiry-options'      => 'gaƒoƒo 1:1 hour,ŋkeke 1:1 day,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite',
'restriction-type'            => 'Mɔɖeɖe:',

# Restrictions (nouns)
'restriction-edit'   => 'Trɔ asi le eŋu',
'restriction-move'   => 'Ɖɔli eƒe nɔƒe',
'restriction-create' => 'Dze egɔme',

# Undelete
'undelete'                  => 'Kpɔ axawo si wotutu',
'viewdeletedpage'           => 'Kpɔ axawo si wotutu',
'undeleteviewlink'          => 'kpɔe',
'undelete-search-submit'    => 'Dii',
'undelete-show-file-submit' => 'Yo',

# Namespace form on various pages
'invert' => 'Trɔ tatiawo tu',

# Contributions
'contributions'       => 'Ezãla ƒe nuŋɔŋlɔwo',
'contributions-title' => '$1 ƒe nuŋɔŋlɔwo',
'mycontris'           => 'Nyeƒe nuŋɔŋlɔwo',
'contribsub2'         => 'Na $1 ($2)',
'uctop'               => '(tametɔ)',
'month'               => 'Tso ɣleti (kple do ŋgɔ):',
'year'                => 'Tso ƒe (kple do ŋgɔ):',

'sp-contributions-newbies' => 'Fia ŋkɔŋlɔla yeyewo ƒe ɖɔɖɔɖowo ko.',
'sp-contributions-talk'    => 'Nyamedzroƒe',
'sp-contributions-search'  => 'Di nuŋɔŋlɔwo',
'sp-contributions-submit'  => 'Dii',

# What links here
'whatlinkshere'       => 'Nusiwo kaa afii ŋu',
'whatlinkshere-title' => 'Axawo siwo ku ɖe "$1" ŋu',
'whatlinkshere-page'  => 'Axa:',
'linkshere'           => "Axa siwo le afisia ku ɖe '''[[:$1]]''' ŋu:",
'nolinkshere'         => "Axa aɖeke meku ɖe '''[[:$1]]''' ŋu o.",
'whatlinkshere-prev'  => '{{PLURAL:$1|do ŋgɔ|$1 do ŋgɔ}}',
'whatlinkshere-next'  => '{{PLURAL:$1|eyome|$1 eyome}}',

# Block/unblock
'blockip'                  => 'Xe mɔ na ezãla sia',
'blockip-legend'           => 'Xe mɔ na ezãla sia',
'ipbexpiry'                => 'Nuwuwu:',
'ipboptions'               => 'gaƒoƒo 2:2 hours,ŋkeke 1:1 day,ŋkeke 3:3 days,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite',
'blockipsuccesssub'        => 'Mɔxexea dze edzi',
'ipb-unblock-addr'         => 'Ɖe $1 ƒe mɔxexe ɖa',
'ipb-blocklist'            => 'Kpɔ mɔxexe siwo li xoxo',
'ipb-blocklist-contribs'   => '$1 ƒe nuŋɔŋlɔwo',
'ipusubmit'                => 'Ɖe mɔxexe sia ɖa',
'ipblocklist-submit'       => 'Dii',
'blocklistline'            => '$1, $2 xemɔ na $3 ($4)',
'infiniteblock'            => 'tegbee',
'expiringblock'            => 'ewunu le gaƒoƒo $2 le ŋkeke $1 dzi',
'createaccountblock'       => 'woxe mɔ na ŋkɔa ŋɔŋlɔ',
'blocklink'                => 'xemɔ',
'unblocklink'              => 'ɖe mɔxexe',
'change-blocklink'         => 'ɖɔli mɔxexe',
'contribslink'             => 'nuŋɔŋlɔ',
'blocklogentry'            => 'xemɔ na [[$1]] vaseɖe $2 megbe $3',
'block-log-flags-nocreate' => 'wo xemɔ na ŋkɔ ŋɔŋlɔ',

# Move page
'move-page-legend'        => 'Ɖɔli eƒe nɔƒe',
'movearticle'             => 'Ɖɔli eƒe nɔƒe:',
'newtitle'                => 'Yi ɖe tanya yeye la:',
'move-watch'              => 'Le ŋku ɖe axa sia ŋu',
'movepagebtn'             => 'Ɖɔli eƒe nɔƒe',
'pagemovedsub'            => 'Axaa ƒe hehe dze edzi',
'movepage-moved'          => '\'\'\'Wohe "$1" vayi "$2"\'\'\'',
'articleexists'           => 'Tanya alo ŋkɔ sia nye axa bubu aɖe tɔ xoxo, alo eda se dzi.
Tia ŋkɔ alo tanya bubu.',
'cantmove-titleprotected' => 'Wòmateŋu ahe axa aɖeke va afii o, elabena wo xemɔ na tanya sia ƒe ŋɔŋlɔ',
'movedto'                 => 'wohee yi',
'1movedto2'               => '[[$1]] wohee yi [[$2]]',

# Export
'export' => 'Ɖo axa siawo ɖa',

# Namespace 8 related
'allmessages'               => 'Gbeƒãɖeɖewo',
'allmessages-filter-all'    => 'Wokatã',
'allmessages-filter-submit' => 'Yi',

# Thumbnails
'thumbnail-more' => 'Ne lolo ɖe edzi',

# Tooltip help for the actions
'tooltip-pt-preferences'          => 'Nyeƒe didiwo',
'tooltip-pt-mycontris'            => 'Wò nuŋɔŋlɔwo ƒe xexlẽme',
'tooltip-pt-login'                => 'Togbɔ be menye ɖe wò hĩa o tse la, mía ve nuwò bena na ŋlɔ ŋkɔ',
'tooltip-pt-logout'               => 'Do le eme',
'tooltip-ca-edit'                 => 'Wòateŋu aɖɔ axa sia ɖo.
Ne ewɔvɔ la, tia "Fiae do ŋgɔ" kpea gbã hafi na dzrae ɖo.',
'tooltip-ca-addsection'           => 'Dze akpa yeye gɔme',
'tooltip-ca-viewsource'           => 'Wo dokpɔ ɖe axa sia ŋu.
Wòateŋu akpɔ alesi woŋlɔe.',
'tooltip-ca-history'              => 'Axa sia ƒe tata xoxoawo',
'tooltip-ca-protect'              => 'Dzɔ axa sia ŋu',
'tooltip-ca-delete'               => 'Tutu axa sia',
'tooltip-ca-move'                 => 'Ɖɔli axa sia ƒe nɔƒe',
'tooltip-search'                  => 'Dii {{SITENAME}}',
'tooltip-search-go'               => 'Yi axa si ƒe ŋkɔ enye esia ne woŋlɔe xoxo',
'tooltip-search-fulltext'         => 'Di nyasiawo le axawo me.',
'tooltip-n-mainpage'              => 'Yi axa si do ŋgɔ',
'tooltip-n-mainpage-description'  => 'Yi axa si do ŋgɔ',
'tooltip-n-recentchanges'         => 'Tɔtrɔ yeyewo le wiki sia me.',
'tooltip-n-randompage'            => 'Kpɔ axa ɖesiaɖe ko',
'tooltip-n-help'                  => 'Nuwo srɔ̃ƒe',
'tooltip-t-whatlinkshere'         => 'Wiki nuŋɔŋlɔwo katã siwo ku ɖe afii ŋuti',
'tooltip-t-recentchangeslinked'   => 'Tɔtrɔ yeyewo le axa siwo ku ɖe axa sia ŋuti',
'tooltip-t-contributions'         => 'Kpɔ nusiwo amesia ŋlɔ',
'tooltip-t-upload'                => 'Ɖo nutatawo kple nuƒoƒowo ɖa',
'tooltip-t-specialpages'          => 'Axa tɔxewo ƒe xexlẽme',
'tooltip-ca-nstab-main'           => 'Kpɔ axa si tanyawo le',
'tooltip-ca-nstab-special'        => 'Axa sia nye axa tɔxe.  Wò mateŋu atrɔ nu aɖeke le edzi o.',
'tooltip-minoredit'               => 'Esia nye tɔtrɔ sue aɖe ko',
'tooltip-save'                    => 'Dzra wòƒe tɔtrɔwo ɖo',
'tooltip-preview'                 => 'Kpɔ wò ɖɔɖɔɖowo do ŋgɔ, mía ve nuwo bena na zãe hafi na dzrae ɖo!',
'tooltip-diff'                    => 'Fia tɔtrɔ siwo newɔ le nuŋɔŋlɔa me',
'tooltip-compareselectedversions' => 'Kpɔ vovototwo le axa sia ƒe tata eve siwo wotia la me',

# Browsing diffs
'previousdiff' => '← Tata xoxoa',
'nextdiff'     => 'Tɔtrɔ yeyea →',

# Special:NewFiles
'newimages' => 'Nutata yeyewo',
'ilsubmit'  => 'Dii',

# External editor support
'edit-externally-help' => '(Kpɔ [http://www.mediawiki.org/wiki/Manual:External_editors gɔmedzedze sewo] na kpekpeɖeŋu bubuwo.)',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'wokatã',
'imagelistall'     => 'wokatã',
'watchlistall2'    => 'katã',
'namespacesall'    => 'wokatã',
'monthsall'        => 'wokatã',

# Multipage image navigation
'imgmultipagenext' => 'axa yometɔ',
'imgmultigo'       => 'Yi!',
'imgmultigoto'     => 'Yi axa $1',

# Table pager
'table_pager_next'         => 'Axa yometɔ',
'table_pager_prev'         => 'Axa si do ŋgɔ',
'table_pager_first'        => 'Axa gbãtɔ',
'table_pager_last'         => 'Axa mamlea',
'table_pager_limit'        => 'Fia nu $1 le axa sia axa dzi',
'table_pager_limit_submit' => 'Yi',

# Watchlist editing tools
'watchlisttools-view' => 'Kpɔ tɔtrɔ siwo hiã la',

# Special:Version
'version' => 'Tata',

# Special:FilePath
'filepath-submit' => 'Yi',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Dii',

# Special:SpecialPages
'specialpages' => 'Axa tɔxewo',

# Special:Tags
'tags-edit' => 'trɔ asi le eŋu',

);
